.. _typing:

Typing
======

.. module:: sisl.typing

sisl will use `typing <https://docs.python.org/3/library/typing.html>`__
to enable static analyzers and to aid users when reading documentation.

The typing types are shown below:

.. autosummary::
   :toctree: generated/

   AxisIntLiteral
   CellAxisStrLiteral
   CellAxisLiteral
   CartesianAxisStrLiteral
   CartesianAxisLiteral
   CellAxis
   CellAxes
   CartesianAxis
   CartesianAxes
   AnyAxis
   AnyAxes

.. autosummary::
   :toctree: generated/

   SimpleIndex
   AtomsIndex
   OrbitalsIndex

.. autosummary::
   :toctree: generated/

   AtomLike
   AtomsLike
   CellLike
   Coord
   CoordOrScalar
   FuncType
   GaugeType
   GeometryLike
   GridLike
   KPoint
   LatticeLike
   LatticeOrGeometry
   LatticeOrGeometryLike
   SileLike
   SparseMatrix
   SparseMatrixExt
   UnitsVar
